Struct BuddyAllocator Copy item path Source pub struct BuddyAllocator {
zone: Zone ,
}[start: end) the physical address range to initialize the PFA.
unsafe because it assumes no data race. This could only work safely during
system initialization.
Formats the value using the given formatter.
Read more Immutably borrows from an owned value.
Read more Mutably borrows from an owned value.
Read more Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.