Struct FrameDesc
Source pub struct FrameDesc {
pfn: u64,
order: usize,
}
return type of the buddy allocation, describes the allocated physical memory
frame(s)
pfn: physical frame number of the starting address
order : number of allocated frames in 2’s order
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.