Zone

Struct Zone 

pub struct Zone {
    pa_range: Range<u64>,
    free_areas: [FreeArea; 11],
}
A contiguous physical memory range to be managed by a (buddy) allocator. free_areas : free-lists for difference sizes (in order of 2).

IMPORTANT: the Zone, or the global ZONE object is unprotected in any sense. One must synchronize the operations via a sane Allocator object.

Fields

pa_range: Range<u64>free_areas: [FreeArea; 11]

Implementations

Source

impl Zone

pub const fn default() -> Self

pub fn get_buddy(&self, frame: &FrameDesc) -> Option<FrameDesc>

pub fn get_buddy_by_pa(&self, pa: u64, order: usize) -> Option<u64>

pub fn contains(&self, frame: &FrameDesc) -> bool